@@ -3,18 +3,17 @@
 #' function to generate empty filevector object (and disk files)
 #' 
 #' @param name name fo the file to be assoiated with new object
-#' 
 #' @param nvariables number of variables (R columns) 
-#' 
 #' @param nobservations number of observations (R rows)
-#' 
 #' @param type data type of the object ("UNSIGNED_SHORT_INT", 
 #' "SHORT_INT", "UNSIGNED_INT", "INT", "FLOAT", "DOUBLE")
+#' @param cachesizeMb what cache size to use for newly generated 'databel' object
+#' @param readonly whether to open new 'databel' in readonly mode
 #' 
-#' @return databel_filtered_R object; also file is created in file system
+#' @return databel object; also file is created in file system
 #' 
 
-make_empty_fvf <- function(name, nvariables, nobservations,type = "DOUBLE") 
+make_empty_fvf <- function(name, nvariables, nobservations,type = "DOUBLE", cachesizeMb = 64, readonly = FALSE) 
 {
 	if (!is(name,"character") || length(name) > 1) stop("file name argument is either non-character or non-scalar");
 	nvariables <- as.integer(nvariables)
@@ -29,7 +28,7 @@ make_empty_fvf <- function(name, nvariables, nobservations,type = "DOUBLE")
 			as.integer(nobservations),as.integer(intype));
 	if (!result) stop(paste("failed to make filevector file",name))
 	print(as.character(name))
-	return(databel_filtered_R(as.character(name)))
+	return(databel(as.character(name),cachesizeMb=cachesizeMb,readonly=readonly))
 	
 }
 
